@@ -131,6 +131,36 @@ class VariableClPassFile(Variable):
     Template file performed at now
     """
 
+class VariableClPassLocation(Variable):
+    """
+    Текущая обрабатываемая локация
+    """
+    value = ""
+
+class VariableClSetupSkipProfile(Variable):
+    """
+    Список пакетов и местоположения шаблонов пропускаемых
+    при настройке профиля
+    """
+    type = "table"
+    value = [[]]
+
+class VariableClSetupSkipPatch(Variable):
+    """
+    Список пакетов и местоположения шаблонов пропускаемых
+    при выполнении патчей
+    """
+    type = "table"
+    value = [[]]
+
+class VariableClSetupSkipMerge(Variable):
+    """
+    Список пакетов и местоположения шаблонов пропускаемых
+    при настройке пакетов системы
+    """
+    type = "table"
+    value = [[]]
+
 class VariableClMergeSet(ReadonlyVariable):
     """
     Force by package template appling
@@ -337,10 +367,33 @@ class VariableClEmergeInfo(ReadonlyVariable):
     def get(self):
         return filter(lambda x:x.startswith('PORTDIR_OVERLAY=') or \
                                x.startswith('EMERGE') or \
+                               x.startswith('PKGDIR=') or \
                                x.startswith('PORTDIR='),
                process("/usr/bin/emerge","--ask=n","--info",
                        envdict=os.environ).read().split('\n'))
 
+class VariableClPkgdir(ReadonlyVariable):
+    """
+    PKGDIR
+    """
+    def get(self):
+        emergeInfo = self.Get('cl_emerge_info')
+        for line in filter(lambda x:x.startswith("PKGDIR="),
+                           emergeInfo):
+            return line.partition("=")[2].strip('\n"\'')
+        return ""
+
+class VariableClPortdir(ReadonlyVariable):
+    """
+    PORTDIR
+    """
+    def get(self):
+        emergeInfo = self.Get('cl_emerge_info')
+        for line in filter(lambda x:x.startswith("PORTDIR="),
+                           emergeInfo):
+            return line.partition("=")[2].strip('\n"\'')
+        return ""
+
 class VariableClPortdirOverlay(ReadonlyVariable):
     """
     Overlays path
